==> dde-daemon_5.12.52.orig.tar.xz: dde-daemon-5.12.52/misc/ts/com.deepin.daemon.Fprintd.policy/policy_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>A autenticación é necesaria para engadir un contrasinal de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Engade un contrasinal de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>A autenticación é necesaria para limpar os contrasinais de impresión dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Borrar os contrasinais de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>A autenticación é necesaria para cambiar o nome do contrasinal da marca dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Cambie o nome do contrasinal da pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Para realizar esta acción é necesario contrasinal</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Xestionar contrasinais de impresión dixital</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.97.orig.tar.xz: dde-daemon-5.14.97/misc/ts/com.deepin.daemon.Fprintd.policy/policy_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>A autenticación é necesaria para engadir contrasinal de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Engade un contrasinal de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>A autenticación é necesaria para limpar os contrasinais de impresión dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Borrar os contrasinais de pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>A autenticación é necesaria para cambiar o nome do contrasinal da marca dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Cambie o nome do contrasinal da pegada dixital</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Para realizar esta acción é necesario contrasinal</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Xestionar contrasinais de impresión dixital</translation>
		</message>
	</context>
</TS>
